@@ -45,7 +45,8 @@ deep_helpers = {
 
 
 def render_file(name, env, output_filename=None, no_output=False,
-                no_squash_blanklines=False, debug=False, **render_vars):
+                no_squash_blanklines=False, comment_prefix=None, debug=False,
+                **render_vars):
 
     """Read a configuration template file and render it.
 
@@ -95,6 +96,18 @@ def render_file(name, env, output_filename=None, no_output=False,
         return True
 
 
+    # if we have a prefix for comment stripping set, remove lines
+    # beginning with that (then we can remove consecutive blank lines
+    # next)
+
+    if comment_prefix:
+        non_comment_config_lines = [
+            l for l in config.split("\n")
+                if not re.match(r"^\s*%s(\s+[^\n]*|)$" % comment_prefix, l)]
+
+        config = "\n".join(non_comment_config_lines)
+
+
     # if not disabled, squash blank lines
 
     if not no_squash_blanklines:
@@ -108,7 +121,6 @@ def render_file(name, env, output_filename=None, no_output=False,
         # the last line should end with a single newline
         config = re.sub(r"\n\n+$", r"\n", config)
 
-
     # write output to either standard output or a file, depending on
     # the options specified
 
@@ -138,7 +150,7 @@ def render_file(name, env, output_filename=None, no_output=False,
 
 def render_config(devicename, inventory, env, output_filename,
                   no_output=False, no_squash_blanklines=False,
-                  dump_device=False, debug=False, **vars):
+                  comment_prefix=None, dump_device=False, debug=False, **vars):
 
     """Render the configuration for the specified device and write it
     to either standard output or a file, depending on the command line
@@ -225,8 +237,9 @@ def render_config(devicename, inventory, env, output_filename,
     # render the template configuration file
 
     if not render_file(role_filename, env, output_filename, no_output,
-                       no_squash_blanklines, devicename=devicename,
-                       device=device, inventory=inventory, **vars):
+                       no_squash_blanklines, comment_prefix,
+                       devicename=devicename, device=device,
+                       inventory=inventory, **vars):
 
         print("warning: failed to render template for: %s - skipping"
                   % devicename,
@@ -302,6 +315,14 @@ parser.add_argument(
              "multiple, consecutive blank lines (prevent equivalent of '| "
              "cat -s') in output")
 
+parser.add_argument(
+    "-M", "--comment-prefix",
+    default="##",
+    help="prefix for comments to strip from output (useful if the target "
+             "platform does not natively support comments but they are to be "
+             "used to provide a documented configuration; set to '-' to "
+             "disable stripping")
+
 parser.add_argument(
     "-E", "--list-env",
     action="store_true",
@@ -384,6 +405,7 @@ inventory_dirname = os.path.join(args.config_dirname, args.inventory_dirname)
 output_filename = args.output_filename
 no_output = args.no_output
 no_squash_blanklines = args.no_squash_blanklines
+comment_prefix = None if args.comment_prefix == "-" else args.comment_prefix
 list_env = args.list_env
 dump_inventory = args.dump_inventory
 dump_filepaths = args.dump_filepaths
@@ -563,8 +585,8 @@ for devicename in devicenames:
     try:
         complete_success &= render_config(devicename, inventory, env,
                                           output_filename, no_output,
-                                          no_squash_blanklines, dump_device,
-                                          debug, **vars)
+                                          no_squash_blanklines, comment_prefix,
+                                          dump_device, debug, **vars)
 
     except helpers.HelperBaseException as e:
         # one of the explicit helper exceptions has occurred
