@@ -171,7 +171,7 @@ helpers["re_match"] = re_match_helper
 
 
 
-def re_match_group_helper(pattern, string, *groups):
+def re_match_group_helper(pattern, string, *groups, no_match_msg=None):
     """Helper function for matching strings against regular expressions
     and extract selected groups (marked by parentheses) of text in a
     Jinja2 template, returning them in the form of a tuple, one for
@@ -184,6 +184,11 @@ def re_match_group_helper(pattern, string, *groups):
     This is a wrapper around re.match().group() (re.match() returns a
     Match object and group() is called on that).
 
+    If the match fails, a ValueError() is raised, giving the pattern and
+    string.  A customised error, raised using HelperException(), can be
+    supplied with no_match_msg.  To avoid raising an exception, the
+    string must be separately matched with re_match_helper() first.
+
     Keyword arguments:
 
     pattern -- the regular expression to match against; the required
@@ -193,11 +198,20 @@ def re_match_group_helper(pattern, string, *groups):
 
     *groups -- a list of arguments giving the numbers or names of the
     desired match groups
+
+    no_match_msg=None -- raise a HelperException() with the supplied
+    message, instead of a generic error (which might display the full
+    call stack).  The message will be passed through str.format() with
+    'string' and 'pattern' arguments, if needed
     """
 
     r = re.match(pattern, string)
 
     if r is None:
+        if no_match_msg:
+            raise HelperException(
+                      no_match_msg.format(pattern=pattern, string=string))
+
         raise ValueError(
             "re_match_group() string: %s does not match pattern: %s"
                 % (repr(string), repr(pattern)))
@@ -209,7 +223,7 @@ helpers["re_match_group"] = re_match_group_helper
 
 
 
-def re_match_groups_helper(pattern, string):
+def re_match_groups_helper(pattern, string, no_match_msg=None):
     """Helper function for matching strings against regular expressions
     and extract groups (marked by parentheses) of text in a Jinja2
     template, returning them in the form of a tuple, one for each pair.
@@ -221,20 +235,34 @@ def re_match_groups_helper(pattern, string):
     This is a wrapper around re.match().groups() (re.match() returns a
     Match object and groups() is called on that).
 
+    If the match fails, a ValueError() is raised, giving the pattern and
+    string.  A customised error, raised using HelperException(), can be
+    supplied with no_match_msg.  To avoid raising an exception, the
+    string must be separately matched with re_match_helper() first.
+
     Keyword arguments:
 
     pattern -- the regular expression to match against; the required
     groups to return should be specified using parentheses
 
     string -- the string to match and return the groups of
+
+    no_match_msg=None -- raise a HelperException() with the supplied
+    message, instead of a generic error (which might display the full
+    call stack).  The message will be passed through str.format() with
+    'string' and 'pattern' arguments, if needed
     """
 
     r = re.match(pattern, string)
 
     if r is None:
-        raise ValueError("re_match_groups() string: %s does not "
-                         "match pattern: %s"
-                             % (repr(string), repr(pattern)))
+        if no_match_msg:
+            raise HelperException(
+                     no_match_msg.format(pattern=pattern, string=string))
+
+        raise ValueError(
+            "re_match_groups() string: %s does not match pattern: %s"
+                % (repr(string), repr(pattern)))
 
     return r.groups()
 
